@@ -33,6 +33,7 @@ def url_to_array(url):
     result = requests.get(url, timeout=3)
     if result.ok:
         img = Image.open(io.BytesIO(result.content))
+        img =  img.convert('RGB')
         data =  np.array(img)
         return data
     else:
@@ -49,5 +50,5 @@ def url_to_file(url,filepath = None):
     if filepath is None:
         p = parse.urlparse(url)
         filepath = p.path[1:]
-    i = Image.fromarray(d)
+    i = Image.fromarray(d,"RGB")
     i.save(filepath)
\ No newline at end of file
